diff --git a/Bukkit/src/main/java/com/plotsquared/bukkit/BukkitPlatform.java b/Bukkit/src/main/java/com/plotsquared/bukkit/BukkitPlatform.java index af6faf26f..f0f5a7113 100644 --- a/Bukkit/src/main/java/com/plotsquared/bukkit/BukkitPlatform.java +++ b/Bukkit/src/main/java/com/plotsquared/bukkit/BukkitPlatform.java @@ -270,7 +270,7 @@ public final class BukkitPlatform extends JavaPlugin implements Listener, PlotPl final PlotSquared plotSquared = new PlotSquared(this, "Bukkit"); - // FAWE + // FastAsyncWorldEdit if (Settings.FAWE_Components.FAWE_HOOK) { Plugin fawe = getServer().getPluginManager().getPlugin("FastAsyncWorldEdit"); if (fawe != null) { @@ -278,7 +278,7 @@ public final class BukkitPlatform extends JavaPlugin implements Listener, PlotPl Class.forName("com.fastasyncworldedit.bukkit.regions.plotsquared.FaweQueueCoordinator"); faweHook = true; } catch (Exception ignored) { - LOGGER.error("Incompatible version of FAWE to enable hook, please upgrade: https://ci.athion" + + LOGGER.error("Incompatible version of FastAsyncWorldEdit to enable hook, please upgrade: https://ci.athion" + ".net/job/FastAsyncWorldEdit/"); } } @@ -432,7 +432,7 @@ public final class BukkitPlatform extends JavaPlugin implements Listener, PlotPl plotSquared.startExpiryTasks(); - // Once the server has loaded force updating all generators known to P2 + // Once the server has loaded force updating all generators known to PlotSquared TaskManager.runTaskLater(() -> PlotSquared.platform().setupUtils().updateGenerators(true), TaskTime.ticks(1L)); // Services are accessed in order diff --git a/Bukkit/src/main/java/com/plotsquared/bukkit/queue/GenChunk.java b/Bukkit/src/main/java/com/plotsquared/bukkit/queue/GenChunk.java index 4288342d6..c2c57a740 100644 --- a/Bukkit/src/main/java/com/plotsquared/bukkit/queue/GenChunk.java +++ b/Bukkit/src/main/java/com/plotsquared/bukkit/queue/GenChunk.java @@ -110,7 +110,7 @@ public class GenChunk extends ScopedQueueCoordinator { /** * Set the world and XZ of the chunk being represented via {@link ChunkWrapper} * - * @param wrap P2 ChunkWrapper + * @param wrap PlotSquared ChunkWrapper */ public void setChunk(@NonNull ChunkWrapper wrap) { chunk = null; diff --git a/Core/src/main/java/com/plotsquared/core/PlotPlatform.java b/Core/src/main/java/com/plotsquared/core/PlotPlatform.java index 50acf9ed1..cd3643fef 100644 --- a/Core/src/main/java/com/plotsquared/core/PlotPlatform.java +++ b/Core/src/main/java/com/plotsquared/core/PlotPlatform.java @@ -359,9 +359,9 @@ public interface PlotPlatform
extends LocaleHolder {
@NonNull String toLegacyPlatformString(@NonNull Component component);
/**
- * Returns if the FAWE-P2 hook is active/enabled
+ * Returns if the FastAsyncWorldEdit-PlotSquared hook is active/enabled
*
- * @return status of FAWE-P2 hook
+ * @return status of FastAsyncWorldEdit-PlotSquared hook
*/
default boolean isFaweHooking() {
return false;
diff --git a/Core/src/main/java/com/plotsquared/core/PlotSquared.java b/Core/src/main/java/com/plotsquared/core/PlotSquared.java
index 03b526e72..722f45558 100644
--- a/Core/src/main/java/com/plotsquared/core/PlotSquared.java
+++ b/Core/src/main/java/com/plotsquared/core/PlotSquared.java
@@ -1581,7 +1581,7 @@ public class PlotSquared {
}
/**
- * Get if the {@link PlatformReadyEvent} has been sent by WE. There is no way to query this within WE itself.
+ * Get if the {@link PlatformReadyEvent} has been sent by WorldEdit. There is no way to query this within WorldEdit itself.
*/
public boolean isWeInitialised() {
return weInitialised;
diff --git a/Core/src/main/java/com/plotsquared/core/plot/PlotArea.java b/Core/src/main/java/com/plotsquared/core/plot/PlotArea.java
index a45451aeb..21ed04f52 100644
--- a/Core/src/main/java/com/plotsquared/core/plot/PlotArea.java
+++ b/Core/src/main/java/com/plotsquared/core/plot/PlotArea.java
@@ -1379,7 +1379,7 @@ public abstract class PlotArea {
}
/**
- * Get the min height from which P2 will generate blocks. Inclusive.
+ * Get the min height from which PlotSquared will generate blocks. Inclusive.
*
* @since 6.6.0
*/
@@ -1388,7 +1388,7 @@ public abstract class PlotArea {
}
/**
- * Get the max height to which P2 will generate blocks. Inclusive.
+ * Get the max height to which PlotSquared will generate blocks. Inclusive.
*
* @since 6.6.0
*/
diff --git a/Core/src/main/java/com/plotsquared/core/plot/PlotAreaTerrainType.java b/Core/src/main/java/com/plotsquared/core/plot/PlotAreaTerrainType.java
index ba760b9aa..73e473885 100644
--- a/Core/src/main/java/com/plotsquared/core/plot/PlotAreaTerrainType.java
+++ b/Core/src/main/java/com/plotsquared/core/plot/PlotAreaTerrainType.java
@@ -44,7 +44,7 @@ public enum PlotAreaTerrainType {
ORE,
/**
- * Generate everything using the vanilla generator but with PS roads.
+ * Generate everything using the vanilla generator but with PlotSquared roads.
*/
ROAD,
diff --git a/Core/src/main/java/com/plotsquared/core/plot/flag/types/ListFlag.java b/Core/src/main/java/com/plotsquared/core/plot/flag/types/ListFlag.java
index ae1b9da00..8ee15ec3f 100644
--- a/Core/src/main/java/com/plotsquared/core/plot/flag/types/ListFlag.java
+++ b/Core/src/main/java/com/plotsquared/core/plot/flag/types/ListFlag.java
@@ -43,7 +43,7 @@ public abstract class ListFlag
diff --git a/Core/src/main/java/com/plotsquared/core/configuration/Settings.java b/Core/src/main/java/com/plotsquared/core/configuration/Settings.java
index 4f64fbbac..2769cfe99 100644
--- a/Core/src/main/java/com/plotsquared/core/configuration/Settings.java
+++ b/Core/src/main/java/com/plotsquared/core/configuration/Settings.java
@@ -44,7 +44,7 @@ public class Settings extends Config {
@Comment("This value is not configurable. It shows the platform you are using.") // This is a comment
@Final
- public static String PLATFORM; // These values are set from P2 before loading
+ public static String PLATFORM; // These values are set from PlotSquared before loading
@Comment({"Show additional information in console. It helps us at IntellectualSites to find out more about an issue.",
"Leave it off if you don't need it, it can spam your console."})
@@ -634,10 +634,10 @@ public class Settings extends Config {
}
- @Comment("Enable or disable all of or parts of the FAWE-P2 hook")
+ @Comment("Enable or disable all of or parts of the FastAsyncWorldEdit-PlotSquared hook")
public static final class FAWE_Components {
- @Comment("Use FAWE for queue handling.")
+ @Comment("Use FastAsyncWorldEdit for queue handling.")
public static boolean FAWE_HOOK = true;
public static boolean CUBOIDS = true;
public static boolean CLEAR = true;